@@ -9,14 +9,18 @@ from gitflow_api.deploy.deploy import Deploy
 class Pypi(Deploy):
 
     def __init__(self):
-        super(Pypi, self).__init__()
+        super(Pypi, self).__init__(Pypi.__class__)
+        self.__qualname__ = 'Pypi'
 
     def deploy(self):
         # remove dist and build files
-        shutil.rmtree('dist')
-        shutil.rmtree('build')
+        try:
+            shutil.rmtree('dist')
+            shutil.rmtree('build')
+        except FileNotFoundError:
+            print('Skipping deleting folder')
 
-        cmd = 'python setup.py sdist bdist_wheel'
+        cmd = 'python3 setup.py sdist bdist_wheel'
         check_call(cmd, shell=True)
 
         cmd = 'twine upload dist/*'
